Keep to < 80 cols


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@26177 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp b/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
index a9d0cc0..820fb4e 100644
--- a/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
+++ b/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
@@ -1563,12 +1563,12 @@
   return DAG.getNode(ISD::ADD, VT, Base, DAG.getConstant(Offset, VT));
 }
 
 /// MeetMaxMemopRequirement - Determines if the number of memory ops required
 /// to replace the memset / memcpy is below the threshold. It also returns the
 /// types of the sequence of  memory ops to perform memset / memcpy.
-static bool MeetMaxMemopRequirement(std::vector<MVT::ValueType> &MemOps,
-                                    unsigned Limit,
-                                    uint64_t Size, unsigned Align, TargetLowering &TLI) {
+static bool MeetsMaxMemopRequirement(std::vector<MVT::ValueType> &MemOps,
+                                     unsigned Limit, uint64_t Size,
+                                     unsigned Align, TargetLowering &TLI) {
   MVT::ValueType VT;
 
   if (TLI.allowsUnalignedMemoryAccesses()) {
@@ -1633,8 +1633,8 @@
     switch (Op) {
     default: break;  // Do nothing for now.
     case ISD::MEMSET: {
-      if (MeetMaxMemopRequirement(MemOps, TLI.getMaxStoresPerMemset(),
-                                  Size->getValue(), Align, TLI)) {
+      if (MeetsMaxMemopRequirement(MemOps, TLI.getMaxStoresPerMemset(),
+                                   Size->getValue(), Align, TLI)) {
         unsigned NumMemOps = MemOps.size();
         unsigned Offset = 0;
         for (unsigned i = 0; i < NumMemOps; i++) {
@@ -1563,12 +1563,12 @@
 }
 
-/// MeetMaxMemopRequirement - Determines if the number of memory ops required
+/// MeetsMaxMemopRequirement - Determines if the number of memory ops required
 /// to replace the memset / memcpy is below the threshold. It also returns the
 /// types of the sequence of  memory ops to perform memset / memcpy.